@@ -1,5 +1,5 @@
-from pyzeebe.credentials.oauth_credentials import OAuthCredentials
-from pyzeebe.exceptions import InvalidOAuthCredentials, InvalidCamundaCloudCredentials
+from mpyzeebe.credentials.oauth_credentials import OAuthCredentials
+from mpyzeebe.exceptions import InvalidOAuthCredentials, InvalidCamundaCloudCredentials
 
 
 class CamundaCloudCredentials(OAuthCredentials):
