@@ -40,7 +40,7 @@ class ZeebeAdapterBase(object):
     @staticmethod
     def _create_channel(connection_uri: str, credentials: BaseCredentials = None,
                         secure_connection: bool = False) -> grpc.Channel:
-        maxMsgLength = 30 * 1024 * 1024
+        maxMsgLength = 100 * 1024 * 1024
         if credentials:
             return grpc.secure_channel(connection_uri,credentials.grpc_credentials, options=[('grpc.max_message_length', maxMsgLength),
                                          ('grpc.max_send_message_length', maxMsgLength),
@@ -88,6 +88,7 @@ class ZeebeAdapterBase(object):
             self.retrying_connection = False
 
     def _should_retry(self):
+        self._max_connection_retries = -1
         return self._max_connection_retries == -1 or self._current_connection_retries < self._max_connection_retries
 
     def _common_zeebe_grpc_errors(self, rpc_error: grpc.RpcError):
@@ -100,12 +101,14 @@ class ZeebeAdapterBase(object):
             self._current_connection_retries += 1
             if not self._should_retry():
                 self._close()
-            raise ZeebeGatewayUnavailable()
+            logger.error(rpc_error)
+          #  raise ZeebeGatewayUnavailable()
         elif self.is_error_status(rpc_error, grpc.StatusCode.INTERNAL):
             self._current_connection_retries += 1
             if not self._should_retry():
                 self._close()
-            raise ZeebeInternalError()
+            logger.error(rpc_error)
+          #  raise ZeebeInternalError()
         else:
             logger.error(rpc_error)
             pass
