@@ -1,8 +1,8 @@
 from typing import Callable, List, Dict
 
-from pyzeebe.decorators.zeebe_decorator_base import ZeebeDecoratorBase
-from pyzeebe.job.job import Job
-from pyzeebe.task.exception_handler import ExceptionHandler
+from mpyzeebe.decorators.zeebe_decorator_base import ZeebeDecoratorBase
+from mpyzeebe.job.job import Job
+from mpyzeebe.task.exception_handler import ExceptionHandler
 
 
 class Task(ZeebeDecoratorBase):
